/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataHcpWaypointApplicationTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the Application Template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/data-sources/waypoint_application_template#id DataHcpWaypointApplicationTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Application Template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/data-sources/waypoint_application_template#name DataHcpWaypointApplicationTemplate#name}
    */
    readonly name?: string;
    /**
    * The ID of the HCP project where the Waypoint Application Template is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/data-sources/waypoint_application_template#project_id DataHcpWaypointApplicationTemplate#project_id}
    */
    readonly projectId?: string;
}
export interface DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetails {
}
export declare function dataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetailsToTerraform(struct?: DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetails): any;
export declare function dataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetailsToHclTerraform(struct?: DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetails): any;
export declare class DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetails | undefined;
    set internalValue(value: DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetails | undefined);
    get name(): string;
    get terraformProjectId(): string;
}
export interface DataHcpWaypointApplicationTemplateTerraformNoCodeModule {
}
export declare function dataHcpWaypointApplicationTemplateTerraformNoCodeModuleToTerraform(struct?: DataHcpWaypointApplicationTemplateTerraformNoCodeModule): any;
export declare function dataHcpWaypointApplicationTemplateTerraformNoCodeModuleToHclTerraform(struct?: DataHcpWaypointApplicationTemplateTerraformNoCodeModule): any;
export declare class DataHcpWaypointApplicationTemplateTerraformNoCodeModuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpWaypointApplicationTemplateTerraformNoCodeModule | undefined;
    set internalValue(value: DataHcpWaypointApplicationTemplateTerraformNoCodeModule | undefined);
    get source(): string;
    get version(): string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/data-sources/waypoint_application_template hcp_waypoint_application_template}
*/
export declare class DataHcpWaypointApplicationTemplate extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "hcp_waypoint_application_template";
    /**
    * Generates CDKTF code for importing a DataHcpWaypointApplicationTemplate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataHcpWaypointApplicationTemplate to import
    * @param importFromId The id of the existing DataHcpWaypointApplicationTemplate that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/data-sources/waypoint_application_template#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataHcpWaypointApplicationTemplate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/data-sources/waypoint_application_template hcp_waypoint_application_template} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataHcpWaypointApplicationTemplateConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataHcpWaypointApplicationTemplateConfig);
    get description(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get labels(): string[];
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    get readmeMarkdownTemplate(): string;
    get summary(): string;
    private _terraformCloudWorkspaceDetails;
    get terraformCloudWorkspaceDetails(): DataHcpWaypointApplicationTemplateTerraformCloudWorkspaceDetailsOutputReference;
    private _terraformNoCodeModule;
    get terraformNoCodeModule(): DataHcpWaypointApplicationTemplateTerraformNoCodeModuleOutputReference;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
