/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WaypointApplicationTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of the template, along with when and why it should be used, up to 500 characters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#description WaypointApplicationTemplate#description}
    */
    readonly description?: string;
    /**
    * List of labels attached to this Application Template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#labels WaypointApplicationTemplate#labels}
    */
    readonly labels?: string[];
    /**
    * The name of the Application Template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#name WaypointApplicationTemplate#name}
    */
    readonly name: string;
    /**
    * The ID of the HCP project where the Waypoint Application Template is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#project_id WaypointApplicationTemplate#project_id}
    */
    readonly projectId?: string;
    /**
    * Instructions for using the template (markdown format supported
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#readme_markdown_template WaypointApplicationTemplate#readme_markdown_template}
    */
    readonly readmeMarkdownTemplate?: string;
    /**
    * A brief description of the template, up to 110 characters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#summary WaypointApplicationTemplate#summary}
    */
    readonly summary: string;
    /**
    * Terraform Cloud Workspace details
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#terraform_cloud_workspace_details WaypointApplicationTemplate#terraform_cloud_workspace_details}
    */
    readonly terraformCloudWorkspaceDetails: WaypointApplicationTemplateTerraformCloudWorkspaceDetails;
    /**
    * Terraform Cloud No-Code Module details
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#terraform_no_code_module WaypointApplicationTemplate#terraform_no_code_module}
    */
    readonly terraformNoCodeModule: WaypointApplicationTemplateTerraformNoCodeModule;
}
export interface WaypointApplicationTemplateTerraformCloudWorkspaceDetails {
    /**
    * Name of the Terraform Cloud Workspace
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#name WaypointApplicationTemplate#name}
    */
    readonly name: string;
    /**
    * Terraform Cloud Project ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#terraform_project_id WaypointApplicationTemplate#terraform_project_id}
    */
    readonly terraformProjectId: string;
}
export declare function waypointApplicationTemplateTerraformCloudWorkspaceDetailsToTerraform(struct?: WaypointApplicationTemplateTerraformCloudWorkspaceDetails | cdktf.IResolvable): any;
export declare function waypointApplicationTemplateTerraformCloudWorkspaceDetailsToHclTerraform(struct?: WaypointApplicationTemplateTerraformCloudWorkspaceDetails | cdktf.IResolvable): any;
export declare class WaypointApplicationTemplateTerraformCloudWorkspaceDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WaypointApplicationTemplateTerraformCloudWorkspaceDetails | cdktf.IResolvable | undefined;
    set internalValue(value: WaypointApplicationTemplateTerraformCloudWorkspaceDetails | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _terraformProjectId?;
    get terraformProjectId(): string;
    set terraformProjectId(value: string);
    get terraformProjectIdInput(): string | undefined;
}
export interface WaypointApplicationTemplateTerraformNoCodeModule {
    /**
    * No-Code Module Source
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#source WaypointApplicationTemplate#source}
    */
    readonly source: string;
    /**
    * No-Code Module Version
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#version WaypointApplicationTemplate#version}
    */
    readonly version: string;
}
export declare function waypointApplicationTemplateTerraformNoCodeModuleToTerraform(struct?: WaypointApplicationTemplateTerraformNoCodeModule | cdktf.IResolvable): any;
export declare function waypointApplicationTemplateTerraformNoCodeModuleToHclTerraform(struct?: WaypointApplicationTemplateTerraformNoCodeModule | cdktf.IResolvable): any;
export declare class WaypointApplicationTemplateTerraformNoCodeModuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WaypointApplicationTemplateTerraformNoCodeModule | cdktf.IResolvable | undefined;
    set internalValue(value: WaypointApplicationTemplateTerraformNoCodeModule | cdktf.IResolvable | undefined);
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template hcp_waypoint_application_template}
*/
export declare class WaypointApplicationTemplate extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_waypoint_application_template";
    /**
    * Generates CDKTF code for importing a WaypointApplicationTemplate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WaypointApplicationTemplate to import
    * @param importFromId The id of the existing WaypointApplicationTemplate that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WaypointApplicationTemplate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.87.1/docs/resources/waypoint_application_template hcp_waypoint_application_template} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WaypointApplicationTemplateConfig
    */
    constructor(scope: Construct, id: string, config: WaypointApplicationTemplateConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _labels?;
    get labels(): string[];
    set labels(value: string[]);
    resetLabels(): void;
    get labelsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _readmeMarkdownTemplate?;
    get readmeMarkdownTemplate(): string;
    set readmeMarkdownTemplate(value: string);
    resetReadmeMarkdownTemplate(): void;
    get readmeMarkdownTemplateInput(): string | undefined;
    private _summary?;
    get summary(): string;
    set summary(value: string);
    get summaryInput(): string | undefined;
    private _terraformCloudWorkspaceDetails;
    get terraformCloudWorkspaceDetails(): WaypointApplicationTemplateTerraformCloudWorkspaceDetailsOutputReference;
    putTerraformCloudWorkspaceDetails(value: WaypointApplicationTemplateTerraformCloudWorkspaceDetails): void;
    get terraformCloudWorkspaceDetailsInput(): cdktf.IResolvable | WaypointApplicationTemplateTerraformCloudWorkspaceDetails | undefined;
    private _terraformNoCodeModule;
    get terraformNoCodeModule(): WaypointApplicationTemplateTerraformNoCodeModuleOutputReference;
    putTerraformNoCodeModule(value: WaypointApplicationTemplateTerraformNoCodeModule): void;
    get terraformNoCodeModuleInput(): cdktf.IResolvable | WaypointApplicationTemplateTerraformNoCodeModule | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
